@@ -23,6 +23,11 @@ class HTTPConflict(HTTPException):
     message = 'A resource with this ID already exists'
 
 
+class HTTPForbidden(HTTPException):
+    code = 403
+    message = 'A resource with this ID already exists'
+
+
 class HTTPBadRequest(HTTPException):
     code = 400
     message = 'This request can not be fulfilled.'
